package com.supermap.samplecode.data;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Frame;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTree;
import javax.swing.SwingUtilities;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;

import com.supermap.data.Dataset;
import com.supermap.data.Datasets;
import com.supermap.data.Datasource;
import com.supermap.data.Datasources;
import com.supermap.data.Layouts;
import com.supermap.data.Maps;
import com.supermap.data.Scenes;
import com.supermap.data.Workspace;

/**
 * <p>
 * Title:工作空间树状结构
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------版权声明----------------------------
 * 此文件为SuperMap Objects Java 的示范代码 
 * 版权所有：北京超图软件股份有限公司
 * ----------------------------------------------------------------
 * ---------------------SuperMap iObjects Java 示范程序说明------------------------
 * 
 * 1、范例简介：展示工作空间的树状结构，包括数据源、地图、三维场景、布局、符号库
 * 2、示例数据：安装目录\SampleData\City\Changchun.smwu；
 * 3、关键类型/成员: 
 *      Workspace.getDatasources 方法
 *      Workspace.getMaps 方法
 *      Workspace.getScenes 方法
 *      Workspace.getLayouts 方法
 *      Workspace.getResources 方法
 * 4、使用步骤：
 *  (1)点击数据集叶节点，可得到数据集相关信息
 *  (2)点击地图叶节点，可得到地图及图层的基本信息
 *  (3)点击三维场景叶节点，可得到三维场景的基本信息
 *  (4)点击布局叶节点，可得到布局的基本信息
 *  (5)点击符号库叶节点，可得到符号库中符号的名称
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: 北京超图软件股份有限公司
 * </p>
 * 
 */

/**
 * <p>
 * Title:工作空间树状结构
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------Copyright Statement----------------------------
 * SuperMap Objects Java Sample Code 
 * Copyright: SuperMap Software Co., Ltd. All Rights Reserved.
 * ------------------------------------------------------------------------------
 *-----------------------Description--------------------------
 * 
 * 1、Sample Code Description：This sample demonstrates the tree structure of workspace including datasource, map, scene, layout,symbol library.
 * 2、Sample Data Location：Installation directory\SampleData\City\Changchun.smwu；
 * 3、Key Classes/Methods
 *      Workspace.getDatasources method
 *      Workspace.getMaps method
 *      Workspace.getScenes method
 *      Workspace.getLayouts method
 *      Workspace.getResources method
 * 4、Procedures:
 *  (1)Click the node of datasources to get the information of the datasources.
 *  (2)Click the node of maps to get the information of the maps and layers.
 *  (3)Click the node of scenes to get the information of the scenes.
 *  (4)Click the node of layouts to get the information of the layouts.
 *  (5)Click the node of resources to get the information of the resources.
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: SuperMap Software Co., Ltd.
 * </p>
 * 
 */

public class MainFrame extends JFrame {

	private static final long serialVersionUID = 1L;

	private JPanel m_contentPane;

	private Workspace m_workspace;

	private SampleRun m_sampleRun;

	private JScrollPane m_scrollPaneWorkspaceTree;

	private JPanel m_panelWorkspaceTree;

	private JTree m_treeWorkspace;

	private JScrollPane m_scrollPaneInfo;
	
	private JTextArea m_textAreaInfo;
	
	/**
	 * 程序入口点
	 * The entrance of the programme.
	 */
	public static void main(String[] args) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				MainFrame thisClass = new MainFrame();
				thisClass.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
				thisClass.setVisible(true);
			}
		});
	}

	/**
	 * 构造函数
	 * The constructor.
	 */
	public MainFrame() {
		super();
		initialize();
	}

	/**
	 * 初始化窗体
	 * Initialize the forms.
	 */
	private void initialize() {
		// 最大化显示窗体
		// Maximum the display form.
		this.setExtendedState(Frame.MAXIMIZED_BOTH);
		this.setSize(800, 500);
		m_workspace = new Workspace();
		m_sampleRun = new SampleRun(m_workspace);
		this.setContentPane(getJContentPane());
		this.setTitle(getText("m_title"));
		this.addWindowListener(new java.awt.event.WindowAdapter() {

			// 在窗体关闭时，需要释放相关的资源
			// Dispose resources when closing the form.
			public void windowClosing(java.awt.event.WindowEvent e) {
				m_workspace.dispose();
			}
		});
	}

	/**
	 * 获取m_contentPane
	 * Get the m_contentPane.
	 */
	private JPanel getJContentPane() {
		if (m_contentPane == null) {
			m_contentPane = new JPanel();
			m_contentPane.setLayout(new BorderLayout());
			m_contentPane.add(getScrollPaneWorkspaceTree(), BorderLayout.WEST);
			m_contentPane.add(getScrollPaneInfo(), BorderLayout.CENTER);
		}
		return m_contentPane;
	}

	/**
	 * 获取m_scrollPaneWorkspaceTree
	 * Get the m_scrollPaneWorkspaceTree.
	 */
	private JScrollPane getScrollPaneWorkspaceTree() {
		if (m_scrollPaneWorkspaceTree == null) {
			m_scrollPaneWorkspaceTree = new JScrollPane();
			m_scrollPaneWorkspaceTree.setViewportView(getPanelWorkspaceTree());
			m_scrollPaneWorkspaceTree.setPreferredSize(new Dimension(250, 600));
		}
		return m_scrollPaneWorkspaceTree;
	}

	/**
	 * 获取m_panelWorkspaceTree
	 * Get the m_panelWorkspaceTree.
	 */
	private JPanel getPanelWorkspaceTree() {
		if (m_panelWorkspaceTree == null) {
			m_panelWorkspaceTree = new JPanel();
			m_panelWorkspaceTree.setLayout(new BorderLayout());
			m_panelWorkspaceTree.setSize(600, Frame.MAXIMIZED_VERT);
			m_panelWorkspaceTree.add(getTreeWorkspace(), BorderLayout.CENTER);
		}
		return m_panelWorkspaceTree;
	}

	/**
	 * 获取m_treeWorkspace
	 * Get the m_treeWorkspace.
	 */
	private JTree getTreeWorkspace() {
		if (m_treeWorkspace == null) {
			m_treeWorkspace = new JTree();
			Font font = new Font("Serif", Font.PLAIN, 18); 
			m_treeWorkspace.setFont(font);
			fillTree();
			m_treeWorkspace.addMouseListener(new MouseAdapter() {
				public void mousePressed(MouseEvent e) {
					m_textAreaInfo.setText("");
					m_sampleRun.doMousePressed(e, m_treeWorkspace, m_textAreaInfo);
					
				}
			});
		}
		return m_treeWorkspace;
	}

	/**
	 * 获取m_scrollPaneInfo	
	 * Get the m_scrollPaneInfo.
	 */
	private JScrollPane getScrollPaneInfo() {
		if (m_scrollPaneInfo == null) {
			m_textAreaInfo = new JTextArea();
			Font font = new Font("Serif", Font.PLAIN, 18);
			m_textAreaInfo.setFont(font);
			m_scrollPaneInfo = new JScrollPane(m_textAreaInfo);
		}
		return m_scrollPaneInfo;
	}

	/**
	 * 填充树结构
	 * Initialize the FillTree.
	 */
	private void fillTree() {
		// 根结点为工作空间名
		// Root node is the workspace name.
		DefaultMutableTreeNode rootNode = new DefaultMutableTreeNode(m_workspace
				.getCaption());
		
		// 数据源子结点
		// Datasource node.
		DefaultMutableTreeNode datasourcesNode = new DefaultMutableTreeNode(
				getText("m_datasourcesNode"));
		Datasources datasources = m_workspace.getDatasources();
		for (int i = 0; i < datasources.getCount(); i++) {
			Datasource datasource = datasources.get(i);
			DefaultMutableTreeNode datasourceNode = new DefaultMutableTreeNode(
					datasource.getAlias());
			Datasets datasets = datasource.getDatasets();
			for (int j = 0; j < datasets.getCount(); j++) {
				Dataset dataset = datasets.get(j);
				DefaultMutableTreeNode datasetNode = new DefaultMutableTreeNode(
						dataset.getName());
				datasourceNode.add(datasetNode);
			}
			datasourcesNode.add(datasourceNode);
		}
		rootNode.add(datasourcesNode);

		// 地图子结点
		// Map node.
		DefaultMutableTreeNode mapsNode = new DefaultMutableTreeNode(getText("m_mapsNode"));
		Maps maps = m_workspace.getMaps();
		for (int i = 0; i < maps.getCount(); i++) {
			DefaultMutableTreeNode mapNode = new DefaultMutableTreeNode(maps
					.get(i));
			mapsNode.add(mapNode);
		}
		rootNode.add(mapsNode);

		// 三维场景子结点
		// Scene node.
		DefaultMutableTreeNode scenesNode = new DefaultMutableTreeNode(getText("m_scenesNode"));
		Scenes scenes = m_workspace.getScenes();
		for (int i = 0; i < scenes.getCount(); i++) {
			DefaultMutableTreeNode sceneNode = new DefaultMutableTreeNode(
					scenes.get(i));
			scenes.get(0);
			scenesNode.add(sceneNode);
		}
		rootNode.add(scenesNode);

		// 布局子结点
		// Layout node.
		DefaultMutableTreeNode layoutsNode = new DefaultMutableTreeNode(getText("m_layoutsNode"));
		Layouts layouts = m_workspace.getLayouts();
		for (int i = 0; i < layouts.getCount(); i++) {
			DefaultMutableTreeNode layoutNode = new DefaultMutableTreeNode(
					layouts.get(i));
			layoutsNode.add(layoutNode);
		}
		rootNode.add(layoutsNode);

		// 符号库子结点
		// Resource node.
		DefaultMutableTreeNode resourcesNode = new DefaultMutableTreeNode(getText("m_resourcesNode"));
		DefaultMutableTreeNode symbolMarkerNode = new DefaultMutableTreeNode(getText("m_symbolMarkerNode"));
		DefaultMutableTreeNode symbolLineNode = new DefaultMutableTreeNode(getText("m_symbolLineNode"));
		DefaultMutableTreeNode symbolFillNode = new DefaultMutableTreeNode(getText("m_symbolFillNode"));
		resourcesNode.add(symbolMarkerNode);
		resourcesNode.add(symbolLineNode);
		resourcesNode.add(symbolFillNode);
		rootNode.add(resourcesNode);
		
		DefaultTreeModel model = new DefaultTreeModel(rootNode);
		m_treeWorkspace.setModel(model);
	}
	

	// 根据语言设置text是中文还是英文
		// To change text to English or Chinede by CurrentCulture
		private String getText(String id)
		{
			String text = "";
			if(com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
			{
				if(id == "m_title")
				{
					text = "工作空间树状结构";
				} 
				if(id == "m_datasourcesNode")
				{
					text = "数据源";
				} 
				if(id == "m_mapsNode")
				{
					text = "地图";
				} 
				if(id == "m_scenesNode")
				{
					text = "三维场景";
				} 
				if(id == "m_layoutsNode")
				{
					text = "布局";
				} 
				if(id == "m_resourcesNode")
				{
					text = "资源";
				} 
				if(id == "m_symbolMarkerNode")
				{
					text = "符号库";
				} 
				if(id == "m_symbolLineNode")
				{
					text = "线型库";
				} 
				if(id == "m_symbolFillNode")
				{
					text = "填充库";
				} 
			}
			else
			{
				if(id == "m_title")
				{
					text = "Workspace Tree";
				} 
				if(id == "m_datasourcesNode")
				{
					text = "Datasource";
				} 
				if(id == "m_mapsNode")
				{
					text = "maps";
				} 
				if(id == "m_scenesNode")
				{
					text = "scenes";
				} 
				if(id == "m_layoutsNode")
				{
					text = "layouts";
				} 
				if(id == "m_resourcesNode")
				{
					text = "resources";
				}
				if(id == "m_symbolMarkerNode")
				{
					text = "SymbolMarkerLibrary";
				} 
				if(id == "m_symbolLineNode")
				{
					text = "SymbolLineLibrary";
				} 
				if(id == "m_symbolFillNode")
				{
					text = "SymbolFillLibrary";
				} 
			}
			return text;
		}
	
}

